# CustomObjectBulkJobRequestOperation

The operation that the bulk job performs. Only the users that have the \"Delete Custom Objects\" permission can submit a `delete` bulk job request. Only the users that have the \"Edit Custom Objects\" permission can submit a `create` or `update` bulk job request. See [Platform Permissions](https://knowledgecenter.zuora.com/Billing/Tenant_Management/A_Administrator_Settings/User_Roles/h_Platform_Roles#Platform_Permissions) for more information.

## Enum

* `DELETE` (value: `'delete'`)

* `CREATE` (value: `'create'`)

* `UPDATE` (value: `'update'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


